==> nextcloud-app-spreed-1:15.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/nn_NO.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "Prat",
    "Guest" : "Gjest",
    "File is too big" : "Fila er for stor",
    "Invalid file provided" : "Ugyldig fil",
    "Invalid image" : "Ugyldig bilete",
    "Unknown filetype" : "Ukjend filtype",
    "An error occurred. Please contact your admin." : "Det oppstod ein feil. Ver venleg og kontakt systemadministrator.",
    "Open settings" : "Opne instillingar",
    "Messages" : "Meldingar",
    "Everyone" : "Alle",
    "None" : "Ingen",
    "User" : "Bruker",
    "Disabled" : "Deaktivert",
    "Users" : "Brukarare",
    "Name" : "Namn",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Skapt den",
    "Pending" : "Under vegs",
    "Error" : "Feil",
    "OK" : "OK",
    "Copy link" : "Kopier lenkje",
    "Dismiss" : "Forkast",
    "Grid view" : "Rutenett visning",
    "Back" : "Tilbake",
    "Favorite" : "Favoritt",
    "Description" : "Skildring",
    "Notifications" : "Varsel",
    "Leave conversation" : "Forlat samtalen",
    "Delete conversation" : "Slett samtale",
    "Allow guests" : "Tillat gjester",
    "Password protection" : "Password protection",
    "Enter a password" : "Skriv inn eit passord",
    "Save" : "Lagre",
    "Edit" : "Endra",
    "More information" : "Meir informasjon",
    "Delete" : "Slett",
    "Password" : "Passord",
    "Login" : "Login",
    "Nickname" : "Kallenamn",
    "Client ID" : "Klient-ID",
    "Calls" : "Samtalar",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Grupper",
    "Circles" : "Sirklar",
    "Password protect" : "Vern med passord",
    "Add participants" : "Legg til deltakarar",
    "Close" : "Lukk",
    "Conversation name" : "Samtale namn",
    "Unread messages" : "Meldingar er ikkje lest",
    "Message sent" : "Melding sendt",
    "Reply" : "Svare",
    "Reply privately" : "Svar privat",
    "Today" : "I dag",
    "Yesterday" : "i går",
    "Record voice message" : "Ta opp lyd melding ",
    "Send message" : "Send melding",
    "Settings" : "Instillingar",
    "Demote from moderator" : "Nedrykk frå moderator",
    "Promote to moderator" : "Fremje til moderator",
    "Remove group and members" : "Eksterne gruppe og medlemmar",
    "Remove participant" : "Eksterne deltakarar",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Deltakarar",
    "Chat" : "Lynmelding",
    "Details" : "Detaljar",
    "Privacy" : "Personvern",
    "Keyboard shortcuts" : "Tastatursnarvegar",
    "Search" : "Search",
    "Rename conversation" : "Eksterne samtalar ",
    "Send" : "Send",
    "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
    "Join a conversation or start a new one" : "Delta i ein samtale eller start ein ny ein",
    "Files" : "Filer",
    "Other" : "Anna",
    "Away" : "Borte",
    "Default" : "Standard",
    "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
    "Saved" : "Lagra"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1:17.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/nn_NO.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "Prat",
    "Guest" : "Gjest",
    "File is too big" : "Fila er for stor",
    "Invalid file provided" : "Ugyldig fil",
    "Invalid image" : "Ugyldig bilete",
    "Unknown filetype" : "Ukjend filtype",
    "Open settings" : "Opne instillingar",
    "Messages" : "Meldingar",
    "Everyone" : "Alle",
    "Name" : "Namn",
    "None" : "Ingen",
    "User" : "Bruker",
    "Disabled" : "Deaktivert",
    "Users" : "Brukarare",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Skapt den",
    "Pending" : "Under vegs",
    "Error" : "Feil",
    "OK" : "OK",
    "Back" : "Tilbake",
    "Cancel" : "Avbryt",
    "Copy link" : "Kopier lenkje",
    "Favorite" : "Favoritt",
    "Description" : "Skildring",
    "Personal" : "Personleg",
    "Leave conversation" : "Forlat samtalen",
    "Delete conversation" : "Slett samtale",
    "Password protection" : "Password protection",
    "Save" : "Lagre",
    "Edit" : "Endra",
    "More information" : "Meir informasjon",
    "Delete" : "Slett",
    "Password" : "Passord",
    "Login" : "Login",
    "Nickname" : "Kallenamn",
    "Client ID" : "Klient-ID",
    "Notifications" : "Varsel",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "Grupper",
    "Circles" : "Sirklar",
    "Password protect" : "Vern med passord",
    "Add participants" : "Legg til deltakarar",
    "Close" : "Lukk",
    "Conversation name" : "Samtale namn",
    "Upload" : "Last opp",
    "Files" : "Filer",
    "Unread messages" : "Meldingar er ikkje lest",
    "Message sent" : "Melding sendt",
    "Dismiss" : "Forkast",
    "Reply" : "Svare",
    "Reply privately" : "Svar privat",
    "Today" : "I dag",
    "Yesterday" : "i går",
    "Send message" : "Send melding",
    "Group" : "Gruppe",
    "Record voice message" : "Ta opp lyd melding ",
    "Settings" : "Instillingar",
    "Send" : "Send",
    "Demote from moderator" : "Nedrykk frå moderator",
    "Promote to moderator" : "Fremje til moderator",
    "Remove group and members" : "Eksterne gruppe og medlemmar",
    "Remove participant" : "Eksterne deltakarar",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Deltakarar",
    "Chat" : "Lynmelding",
    "Details" : "Detaljar",
    "Privacy" : "Personvern",
    "Keyboard shortcuts" : "Tastatursnarvegar",
    "Search" : "Search",
    "Open sidebar" : "Opne sidestolpe",
    "Open chat" : "Start lynmelding",
    "Grid view" : "Rutenett visning",
    "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
    "Join a conversation or start a new one" : "Delta i ein samtale eller start ein ny ein",
    "Other" : "Anna",
    "Away" : "Borte",
    "Default" : "Standard",
    "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
    "Rename conversation" : "Eksterne samtalar "
},
"nplurals=2; plural=(n != 1);");
